@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 """ntphostoffset_ - Munin Plugin to monitor time offset of remote host using NTP.
 
 Requirements
@@ -11,8 +11,8 @@ Wild Card Plugin
 
 
 Multigraph Plugin - Graph Structure
-   - ntp_host_stratum_
-   - ntp_host_stat_
+   - ntp_host_stratum
+   - ntp_host_stat
 
 
 Environment Variables
