@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 """phpapcstats - Munin Plugin for monitoring PHP APC Cache.
 
 Requirements
@@ -26,6 +26,7 @@ Environment Variables
   password:       Password in case authentication is required for access to 
                   APC Status page.
   monpath:        APC status script path relative to Document Root.
+                  (Default: apcinfo.php)
   ssl:            Use SSL if yes. (Default: no)
   include_graphs: Comma separated list of enabled graphs. 
                   (All graphs enabled by default.)
@@ -37,8 +38,8 @@ Environment Variables
 
 """
 # Munin  - Magic Markers
-#%# family=manual
-#%# capabilities=noautoconf nosuggest
+#%# family=auto
+#%# capabilities=autoconf nosuggest
 
 import sys
 from pymunin import MuninGraph, MuninPlugin, muninMain
@@ -72,7 +73,7 @@ class MuninPHPapcPlugin(MuninPlugin):
         MuninPlugin.__init__(self, argv, env, debug)
         
         self._host = self.envGet('host')
-        self._port = self.envGet('port')
+        self._port = self.envGet('port', None, int)
         self._user = self.envGet('user')
         self._monpath = self.envGet('monpath')
         self._password = self.envGet('password')
@@ -175,6 +176,16 @@ class MuninPHPapcPlugin(MuninPlugin):
                              stats['cache_sys']['expunges'])
             self.setGraphVal('php_apc_expunge', 'usercache', 
                              stats['cache_user']['expunges'])
+    
+    def autoconf(self):
+        """Implements Munin Plugin Auto-Configuration Option.
+        
+        @return: True if plugin can be  auto-configured, False otherwise.
+                 
+        """
+        apcinfo = APCinfo(self._host, self._port, self._user, self._password, 
+                          self._monpath, self._ssl)
+        return apcinfo is not None
 
             
 def main():
