@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 """phpfpmstats - Munin Plugin for monitoring PHP FPM (Fast Process Manager).
 
 Requirements
@@ -19,7 +19,7 @@ Environment Variables
   port:           Web Server Port. (Default: 80, SSL: 443)
   user:           User in case authentication is required for access to 
                   FPM Status page.
-  password:       User in case authentication is required for access to 
+  password:       Password in case authentication is required for access to 
                   FPM Status page.
   monpath:        FPM status page path relative to Document Root.
                   (Default: fpm_status.php)
@@ -34,8 +34,8 @@ Environment Variables
 
 """
 # Munin  - Magic Markers
-#%# family=manual
-#%# capabilities=noautoconf nosuggest
+#%# family=auto
+#%# capabilities=autoconf nosuggest
 
 import sys
 from pymunin import MuninGraph, MuninPlugin, muninMain
@@ -69,7 +69,7 @@ class MuninPHPfpmPlugin(MuninPlugin):
         MuninPlugin.__init__(self, argv, env, debug)
         
         self._host = self.envGet('host')
-        self._port = self.envGet('port')
+        self._port = self.envGet('port', None, int)
         self._user = self.envGet('user')
         self._monpath = self.envGet('monpath')
         self._password = self.envGet('password')
@@ -108,6 +108,16 @@ class MuninPHPfpmPlugin(MuninPlugin):
                              stats['idle processes'])
             self.setGraphVal('php_fpm_processes', 'total', 
                              stats['total processes'])
+    
+    def autoconf(self):
+        """Implements Munin Plugin Auto-Configuration Option.
+        
+        @return: True if plugin can be  auto-configured, False otherwise.
+                 
+        """
+        fpminfo = PHPfpmInfo(self._host, self._port, self._user, self._password, 
+                             self._monpath, self._ssl)
+        return fpminfo is not None
 
 
 def main():
