@@ -125,11 +125,48 @@ class MySQLinfo:
             val = util.parse_value(row[1])
             info_dict[key] = val
         return info_dict
+    
+    def getProcessStatus(self):
+        """Returns number of processes discriminated by state.
+        
+        @return: Dictionary mapping process state to number of processes.
+        
+        """
+        info_dict = {}
+        cur = self._conn.cursor()
+        cur.execute("""SHOW FULL PROCESSLIST;""")
+        rows = cur.fetchall()
+        if rows:
+            for row in rows:
+                if row[6] == '':
+                    state = 'idle'
+                elif row[6] is None:
+                    state = 'other'
+                else:
+                    state = str(row[6]).replace(' ', '_').lower()
+                info_dict[state] = info_dict.get(state, 0) + 1
+        return info_dict
+    
+    def getProcessDatabase(self):
+        """Returns number of processes discriminated by database name.
+        
+        @return: Dictionary mapping database name to number of processes.
+        
+        """
+        info_dict = {}
+        cur = self._conn.cursor()
+        cur.execute("""SHOW FULL PROCESSLIST;""")
+        rows = cur.fetchall()
+        if rows:
+            for row in rows:
+                db = row[3]
+                info_dict[db] = info_dict.get(db, 0) + 1
+        return info_dict
      
     def getDatabases(self):
         """Returns list of databases.
         
-        @return: List of database schemas.
+        @return: List of databases.
         
         """
         cur = self._conn.cursor()
